%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% For a process with spectral density $f(freq)~C /freq^{2d)$ for $freq->0$,
% computation of an adaptive version of estimator of the memory parameter $d$
% using multidimensional IR statistic + Goodness-of-fit test of LRD
%
% Input :  * X a sample of a time series with a memory parameter d in
%            [-0.5,1.25] (its spectral density behaves as $C x^{-2d}$ when x->0
%          * printout (optional)
%
%
% Output : * dest2: estimator of d
%          * CHIN the test statistic which is 0 if the goodness-of-fit test
%            is accepted, 1 else
%          * mest: the estimated minimal window length 
%          * SN the stationarity test statistic which is 0 if the stationarity
%            is accepted, 1 else
%          * NSN the nonstationarity test statistic which is 0 if the nonstationarity
%            is accepted, 1 else
%
% (more details in Bardet and Dola, 2010, 2012)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [dest2,TN,CHIN,mest,SN,NSN]=MirAdaptif5(X,printout)


n=length(X); % Taille des echantillons
%p=fix(log(n)*1.5);
%p=10; % Nombre de fenetres choisies pour l'adaptation
if n<120 p=5; end
if n>=120 p=10; end
if n>=800 p=15; end
if n>=1000 p=20; end
TN=0;
mest=0;
dest2=0;
m2=0;
m3=0;
alpha=(5:(10*log(n)))/(10*log(n)); % Differentes tailles de fenetres choisies
mm=0;
mm=fix(n.^alpha);
m2=0;
pm=0;
IR=0;
dd=0;
for ell=1:(length(mm)-1)
    if mm(ell+1)>mm(ell)
        pm=pm+1;
        m2(pm)=mm(ell+1);
    end
end

%for ell=(length(mm)-1):(-1):1
 %   if mm(ell+1)==mm(ell)
  %      mm(ell)=mm(ell);
   % end
%end
m3=m2(find(m2>1 ));
mmm=m3(find(m3<(n/(5*p))));
lmmm=length(mmm);  
dfi=0;

    % Determination de la plus petite taille de fenetre
    for k=1:lmmm
        IR=0;
        dd=0;
        Sig=0;
        dsig=0;
        for s=1:p
            IR(s)=IRstat2(X,s*mmm(k));
            dd(s)=Lambdainv2(IR(s));
        end
        dfi(k)=dd(1);
        %ddmean=mean(dd);
        %QQN(k)=(dd-ddmean)*(dd-ddmean)';
        Sig=SigMir2(dd(1),p);
        dsig=inv(ones(1,p)*inv(Sig)*ones(p,1))*ones(1,p)*inv(Sig)*dd';
        QN(k)=sqrt(n/mmm(k))*(dd-dsig)*inv(Sig)*(dd-dsig)';
        %QN(k)=(n/mmm(k))*(dd-dd(1))*inv(Sig)*(dd-dd(1))';
    end
    aa=0;
    Q=min(QN(1:lmmm));
    aa=max(find(QN==Q));
    mest=mmm(aa);
    mest=mest+1;
    
    % Calcul de l'estimateur de d + Test avec p echelle
        IR=0;
        dd=0;
        Sig=0;
        for s=1:p
            IR(s)=IRstat2(X,s*mest);
            dd(s)=Lambdainv2(IR(s));
        end
        % calcul de la matrice de covariance asymptotique
        Sig=SigMir2(dd(1),p);
        dest2=inv(ones(1,p)*inv(Sig)*ones(p,1))*ones(1,p)*inv(Sig)*dd';  % Estimator of d
        TN=(n/mest)*(dd-dest2)*inv(Sig)*(dd-dest2)';  % Test 
        CHIN=(TN>chi2inv(0.95,p-1));
        
        if p==5
        SN=(dest2>0.5+0.9082*1.645*sqrt(mest)/sqrt(n));
        end
        if p==10
        SN=(dest2>0.5+0.8289*1.645*sqrt(mest)/sqrt(n));
        end
        if p==15
        SN=(dest2>0.5+0.8016*1.645*sqrt(mest)/sqrt(n));
        end
        if p==20
        SN=(dest2>0.5+0.7861*1.645*sqrt(mest)/sqrt(n));
        end
        if p==5
        NSN=(dest2<0.5-0.9082*1.645*sqrt(mest)/sqrt(n));
        end
        if p==10
        NSN=(dest2<0.5-0.8289*1.645*sqrt(mest)/sqrt(n));
        end
        if p==15
        NSN=(dest2<0.5-0.8016*1.645*sqrt(mest)/sqrt(n));
        end
        if p==20
        NSN=(dest2<0.5-0.7861*1.645*sqrt(mest)/sqrt(n));
        end

if nargin>1
    plot(mmm,dfi)
    hold on
    plot(mest*(1:p),dest2*ones(1:p,1),'*')
    hold off
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function ir=IRstat2(x,m)

 Y=0;
 n=length(x);
 YY=filter(ones(1,m),1,x);
 Y=YY(m:n);
 ir=mean(abs(Y((1+2*m):(n-m))- Y(1:(n-3*m)))./(abs(Y((1+2*m):(n-m))- Y((1+m):(n-2*m)))+abs(Y((1+m):(n-2*m))- Y(1:(n-3*m)))));
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    function de=Lambdainv2(R)

H=0.0001:0.0001:1.9999;
r=(-3.^(2*H)+2.^(2*H+2)-7)./(8-2.^(2*H+1));
Lambda=1/pi*acos(-r)+sqrt(1-r.^2)./(pi*(1-r)).*log(2./(r+1));
de=sum(R>Lambda)/10000-0.5;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function sig=SigMir2(d,p) 

M=0;
%load CovarMIR
M1=[ 0.0350    0.5210    1.1112    1.0832    1.9007    2.0744    1.9340    1.8031    1.9982    2.0167    1.3694
   -0.0072   -0.2386   -0.3563   -0.2537   -0.7063   -0.2794   -0.3258   -0.3845   -0.3847    0.0485    0.2151
    0.0006   -0.0498   -0.0893   -0.3939   -0.2992   -0.0736   -0.5871   -0.5854   -0.4752   -0.3005   -0.3491
    0.0022   -0.0715   -0.2260   -0.1317   -0.0675    0.0009   -0.2842   -0.4176   -0.4691   -0.5295   -0.4769
    0.0006   -0.0945   -0.0473   -0.1842   -0.1589   -0.3554    0.3540   -0.3994   -0.4248   -0.2718   -0.3289
   -0.0025   -0.0438   -0.0609   -0.3665   -0.1905   -0.4088    0.3770   -0.3729   -0.8521   -0.3825   -0.3613
    0.0043    0.0558   -0.0892   -0.3658    0.0064   -0.4044    0.3747   -0.5703   -0.7800   -0.2853   -0.4268
    0.0018    0.0728   -0.1117   -0.2910   -0.0923   -0.4908    0.1537   -0.6705   -0.8633   -0.3880   -0.2679
    0.0052    0.2183   -0.2003   -0.2498   -0.2042   -0.2190   -0.1759   -0.1397   -1.1468   -0.5703   -0.1509
    0.0016    0.2857   -0.1411   -0.1299   -0.5917   -0.0722   -0.1477    0.3492   -1.2950   -0.6080   -0.0244
   -0.0016    0.2740    0.0782   -0.0639   -0.7747   -0.3772   -0.2502    0.4913   -1.5013   -0.5269   -0.0884
   -0.0015    0.2509    0.0997    0.1904   -0.3721   -0.4156   -0.2771    0.4581   -1.2154   -0.4789   -0.2745
   -0.0032    0.2020    0.0538    0.4197   -0.0770   -0.3880   -0.0140    0.4938   -1.0378   -0.2600   -0.4313
    0.0010    0.1800   -0.0290    0.5894    0.2037   -0.4893    0.4674    0.2486   -1.1041    0.0673   -0.5176
   -0.0025    0.0414   -0.0754    0.5759    0.2968   -0.3849    0.8755   -0.1418   -0.7844    0.1653   -0.5275
    0.0018   -0.0362   -0.0993    0.3358    0.5165   -0.5791    1.1286   -0.4110   -0.4273    0.1002   -0.6055
    0.0035   -0.1335   -0.1980    0.3119    0.4743   -0.6433    1.1277   -0.6699   -0.2558    0.0308   -0.6053
   -0.0022   -0.1317   -0.2233    0.4120    0.3207   -0.6282    0.9466   -0.9286    0.2362   -0.0951   -0.5907
    0.0059   -0.1355   -0.1730    0.3295    0.2481   -0.5139    0.6808   -1.0698    0.4774   -0.1787   -0.4314
   -0.0009   -0.0542   -0.3068    0.2893    0.2503   -0.7104    0.3833   -1.1104    0.7120   -0.2157   -0.3174
   -0.0072   -0.2386   -0.3563   -0.2537   -0.7063   -0.2794   -0.3258   -0.3845   -0.3847    0.0485    0.2151
    0.0442    0.8993    1.9401    2.4434    4.3139    3.6109    4.3267    4.6422    3.9790    4.7026    3.7019
   -0.0047    0.0230   -0.0889    0.0051    0.2785    0.5682    1.0718    1.0190    1.8436    2.3302    1.5351
   -0.0067   -0.3580   -0.9030   -0.7895   -1.8413   -1.1212   -1.0824   -1.2148   -0.1296    0.1190   -0.4373
    0.0001   -0.2670   -0.5795   -0.7887   -1.6940   -1.3288   -1.3596   -1.8274   -0.9694   -0.8578   -0.9146
    0.0090   -0.1002   -0.2181   -0.3734   -1.1119   -1.1910   -0.7924   -1.7449   -1.1410   -1.3138   -1.0092
   -0.0021    0.0156   -0.0765   -0.0886   -0.2696   -1.1274   -0.7470   -1.3923   -1.1149   -1.3337   -1.1652
    0.0004    0.0452    0.0073   -0.3053    0.3333   -1.3991   -0.9766   -1.1680   -1.2965   -1.2414   -1.2674
   -0.0008    0.0800    0.1097   -0.4645    0.7635   -1.5371   -1.2177   -1.1003   -1.3366   -1.1036   -1.5881
    0.0010    0.0274    0.4339   -0.6609    0.8349   -1.4944   -1.3360   -1.4686   -1.0394   -1.1030   -1.6542
    0.0001    0.0637    0.5121   -0.5691    0.6220   -0.9371   -0.9417   -1.7541   -0.3254   -1.1635   -1.2265
    0.0045   -0.0509    0.4593   -0.4564    0.4639   -1.0334   -0.7965   -1.6280    0.2827   -1.2563   -0.7675
   -0.0013   -0.0050    0.4040   -0.6721    0.1409   -0.9417   -0.9187   -1.7591    0.6004   -1.1302   -0.3745
   -0.0004    0.0283    0.4766   -0.6502   -0.2308   -0.6556   -0.8033   -1.6445    1.0563   -1.0888   -0.0945
   -0.0023    0.1074    0.2998   -0.5323   -0.4062   -0.3740   -0.8232   -1.6375    1.2423   -1.0962   -0.1231
   -0.0034    0.1650    0.4411   -0.5062   -1.0353   -0.4403   -0.8068   -1.8705    1.3075   -1.2535    0.0442
   -0.0062    0.1922    0.6176   -0.6027   -1.4757   -0.0658   -1.1273   -1.4792    1.0120   -1.2135    0.1377
   -0.0020    0.2989    0.6774   -0.6683   -1.1892    0.2352   -1.2428   -1.2883    0.7901   -1.0259    0.1489
   -0.0012    0.2417    0.4079   -0.5756   -1.0255    0.2406   -0.9616   -1.2962    0.6454   -1.0818    0.1149
    0.0013    0.1360    0.2270   -0.4226   -1.5592    0.0365   -0.7469   -1.1931    0.3290   -1.3605    0.0305
    0.0006   -0.0498   -0.0893   -0.3939   -0.2992   -0.0736   -0.5871   -0.5854   -0.4752   -0.3005   -0.3491
   -0.0047    0.0230   -0.0889    0.0051    0.2785    0.5682    1.0718    1.0190    1.8436    2.3302    1.5351
    0.0401    1.2448    2.7109    4.3692    5.2229    5.3035    6.5326    5.3556    7.9917    6.0124    5.8952
    0.0006    0.5688    0.8513    1.9989    2.2416    2.4311    3.3224    3.1821    4.9002    3.8096    4.3425
   -0.0010   -0.0666   -0.4834   -0.4319   -0.7136   -0.1461    0.0812    0.4292    0.3203    1.0169    1.5998
   -0.0067   -0.5070   -1.0531   -1.5226   -1.9282   -1.7665   -1.5233   -0.8608   -1.6998   -0.6962   -0.0406
   -0.0012   -0.4623   -0.8034   -1.7233   -2.0975   -1.9616   -2.4354   -1.7443   -2.6753   -1.9862   -0.8227
   -0.0034   -0.2257   -0.4847   -1.9022   -1.7416   -2.3795   -3.3270   -2.5275   -2.8275   -2.3753   -1.6166
    0.0006   -0.0466   -0.7316   -1.5319   -1.3293   -2.5203   -3.4525   -3.2862   -2.8240   -2.3830   -2.0122
   -0.0019    0.0728   -0.7259   -1.6793   -0.6560   -2.7252   -3.6414   -3.4391   -2.9482   -2.6885   -2.2459
    0.0010    0.0000   -0.8221   -1.5654   -0.6632   -2.7160   -2.9660   -3.4180   -2.8444   -2.8457   -2.1994
   -0.0008    0.0672   -0.5624   -1.3686   -0.6344   -2.1271   -2.4049   -2.9491   -2.8329   -3.1387   -2.1460
    0.0023    0.1072   -0.3237   -1.2007   -0.6175   -1.6035   -1.9571   -2.3183   -2.8162   -3.2224   -1.7593
    0.0006    0.2487    0.0577   -0.6569   -0.3470   -1.3811   -1.3119   -1.8392   -2.3609   -3.2287   -1.4374
   -0.0041    0.3430    0.2268   -0.3774    0.2446   -0.9239   -1.1899   -1.4194   -1.9515   -3.4339   -1.1536
    0.0072    0.2857    0.1554    0.2993    0.3077   -0.5706   -1.0562   -1.6818   -1.3149   -3.4402   -0.7579
   -0.0020    0.3652    0.0370    0.6082    0.8316   -0.0058   -0.9177   -1.4731   -0.7543   -3.1339   -0.5380
    0.0017    0.2849    0.0559    0.9455    0.8394    0.6334   -1.2524   -1.3635   -0.3568   -2.6516   -0.4342
   -0.0024    0.2144    0.0013    1.1034    0.7164    1.3769   -0.8448   -1.3856    0.2080   -2.0942   -0.3884
   -0.0010    0.1235   -0.1527    0.7796    0.5380    2.1998   -0.6227   -1.1972    0.4515   -1.6198   -0.4645
    0.0022   -0.0715   -0.2260   -0.1317   -0.0675    0.0009   -0.2842   -0.4176   -0.4691   -0.5295   -0.4769
   -0.0067   -0.3580   -0.9030   -0.7895   -1.8413   -1.1212   -1.0824   -1.2148   -0.1296    0.1190   -0.4373
    0.0006    0.5688    0.8513    1.9989    2.2416    2.4311    3.3224    3.1821    4.9002    3.8096    4.3425
    0.0274    1.7461    3.7573    5.3767    7.0823    7.3055    8.2633    8.2421    9.3330    8.4025    8.4245
   -0.0009    0.7784    2.0158    3.4776    5.6102    5.0468    6.3354    6.3406    7.1733    6.6594    7.1013
   -0.0054   -0.2133    0.0975    0.6202    2.4122    1.7807    2.0986    2.6258    3.6000    2.7648    4.0730
   -0.0042   -0.4843   -0.7270   -1.0289   -1.2786   -0.0372   -1.3345   -0.0013    0.5376   -0.6541    1.7004
   -0.0053   -0.5329   -1.0854   -1.9418   -3.1264   -1.2286   -3.3756   -2.3168   -1.3970   -1.8751   -0.2049
   -0.0032   -0.6190   -1.0198   -2.3776   -3.4687   -1.6987   -4.4674   -3.8459   -2.3660   -2.3038   -1.3663
   -0.0026   -0.4567   -1.1928   -2.7360   -2.3947   -1.8508   -5.0264   -3.9514   -3.0336   -2.7895   -2.2434
    0.0014   -0.2604   -0.9717   -2.5526   -1.5275   -1.6710   -4.4884   -3.6899   -3.2168   -3.4420   -2.8903
    0.0019   -0.0927   -0.5347   -2.2281   -0.9178   -1.3940   -3.8803   -3.3424   -3.1406   -4.0762   -3.2674
    0.0025   -0.0971   -0.2977   -1.6440   -0.5253   -1.5429   -3.5904   -2.7230   -3.3846   -4.5135   -3.2118
    0.0027    0.1062   -0.1468   -1.0644    0.0335   -1.9772   -3.0998   -2.0346   -2.8750   -4.6021   -3.2944
   -0.0012    0.0873   -0.2443   -0.9653   -0.0100   -2.2111   -2.9768   -1.2870   -2.5588   -4.9271   -3.0947
   -0.0002   -0.0038   -0.3819   -0.3482   -0.1367   -1.7829   -2.8346   -0.7295   -1.9486   -5.3578   -2.7808
    0.0001    0.0762   -0.7114    0.0487   -0.3478   -1.8736   -2.4201   -0.4396   -1.3533   -5.1804   -2.3505
   -0.0013    0.0422   -0.6242    0.4329   -0.8987   -1.4272   -2.3252   -0.2054   -0.8259   -4.9521   -2.0559
    0.0017    0.1893   -0.7751    0.5332   -1.8219   -1.0229   -2.0837   -0.3847   -0.7108   -4.5978   -1.7490
    0.0006    0.1525   -0.4259    0.3732   -2.2185   -0.2860   -1.6442   -0.7217   -0.4848   -4.0251   -1.4922
    0.0006   -0.0945   -0.0473   -0.1842   -0.1589   -0.3554    0.3540   -0.3994   -0.4248   -0.2718   -0.3289
    0.0001   -0.2670   -0.5795   -0.7887   -1.6940   -1.3288   -1.3596   -1.8274   -0.9694   -0.8578   -0.9146
   -0.0010   -0.0666   -0.4834   -0.4319   -0.7136   -0.1461    0.0812    0.4292    0.3203    1.0169    1.5998
   -0.0009    0.7784    2.0158    3.4776    5.6102    5.0468    6.3354    6.3406    7.1733    6.6594    7.1013
    0.0403    1.8188    4.6836    7.1496   10.6965    8.9255   11.5758   10.5330   12.5561    9.8560   10.2325
   -0.0015    1.1131    3.2391    4.9650    8.5621    7.3484    9.0540    8.2237   10.8801    7.1515    8.6012
    0.0027    0.4209    1.1946    2.0546    3.2873    3.9630    4.7559    4.5983    6.8171    3.3869    5.3895
    0.0015   -0.0518   -0.6430    0.3156   -0.4608    1.2337    0.9742    0.5786    2.5819    1.4884    2.5499
    0.0001   -0.6508   -1.2163   -1.4224   -3.0575    0.1875   -1.8317   -2.6914    0.3830   -0.0571    0.3879
   -0.0051   -0.7862   -1.9723   -2.7344   -3.3438   -0.4415   -3.1271   -3.8477   -0.5918   -1.3058   -1.5500
    0.0025   -0.4765   -2.0227   -2.3627   -3.1963   -0.6722   -3.4971   -3.9668   -1.0535   -2.5068   -2.8651
    0.0009   -0.3669   -1.6305   -1.8090   -2.8705   -1.0177   -3.5447   -3.4729   -1.1803   -3.2189   -3.4355
    0.0029   -0.2954   -1.3963   -0.5822   -2.4997   -1.4571   -3.9188   -2.9215   -1.6621   -3.6972   -3.8504
   -0.0002   -0.1184   -1.1664    0.1328   -2.0151   -1.5931   -3.9415   -2.0988   -1.5047   -3.9133   -4.4160
   -0.0006   -0.1689   -1.0508    0.0039   -2.8146   -2.1513   -4.0192   -1.0525   -1.7682   -4.4781   -4.4936
   -0.0016   -0.2909   -0.8262   -0.0102   -3.4887   -1.8165   -4.4152   -0.2485   -1.5214   -5.0463   -4.3685
   -0.0057   -0.3424   -0.8189   -0.0217   -3.7996   -2.2883   -4.3321    0.2576   -1.1406   -5.3281   -3.8167
    0.0010   -0.2772   -0.4728   -0.4392   -4.1032   -2.2846   -4.9203    0.8002   -0.6600   -5.3431   -3.4955
    0.0063   -0.1389   -0.5461   -0.5723   -4.4959   -2.4839   -5.3986    0.6829   -0.7736   -5.1949   -3.2421
   -0.0032   -0.1889   -0.0075   -0.5858   -4.2827   -2.0230   -5.3240    0.1828   -0.7470   -4.9822   -2.7540
   -0.0025   -0.0438   -0.0609   -0.3665   -0.1905   -0.4088    0.3770   -0.3729   -0.8521   -0.3825   -0.3613
    0.0090   -0.1002   -0.2181   -0.3734   -1.1119   -1.1910   -0.7924   -1.7449   -1.1410   -1.3138   -1.0092
   -0.0067   -0.5070   -1.0531   -1.5226   -1.9282   -1.7665   -1.5233   -0.8608   -1.6998   -0.6962   -0.0406
   -0.0054   -0.2133    0.0975    0.6202    2.4122    1.7807    2.0986    2.6258    3.6000    2.7648    4.0730
   -0.0015    1.1131    3.2391    4.9650    8.5621    7.3484    9.0540    8.2237   10.8801    7.1515    8.6012
    0.0391    2.1897    5.6061    8.4101   12.0085   11.6741   12.8798   12.6357   14.6818    9.2351   11.1419
   -0.0027    1.5357    4.0396    6.7355    8.5800    9.3953   11.2293   11.8386   13.0619    8.1486    9.6410
    0.0021    0.7228    1.5102    4.7854    4.5116    6.0345    7.6335    7.9765    8.7998    6.6714    6.6348
   -0.0018   -0.0154   -0.1180    1.8418    0.5878    3.4821    3.4680    3.4707    6.0824    4.1911    3.5385
   -0.0011   -0.3695   -1.5013   -0.1513   -1.4689    1.6313    0.3413    0.7461    4.2402    2.0029    0.6268
    0.0012   -0.5494   -2.2249   -1.0778   -2.8209   -0.1963   -1.9135   -1.0846    2.4377    0.0232   -1.1945
   -0.0024   -0.8109   -2.4620   -1.7003   -3.7049   -1.5007   -3.3493   -2.2810    1.2026   -1.2107   -2.1125
   -0.0014   -0.7919   -2.5938   -1.7307   -3.6840   -2.4828   -4.5885   -2.7551   -0.1687   -2.0954   -3.1177
   -0.0033   -0.7233   -1.9899   -2.1748   -3.1941   -2.4855   -5.3876   -3.1549   -1.2502   -2.7500   -4.0090
    0.0014   -0.7374   -1.5570   -2.9520   -3.8279   -2.7975   -5.5930   -2.7263   -2.3331   -3.5805   -4.3059
   -0.0063   -0.5940   -0.8325   -3.3217   -4.3846   -2.1566   -5.8934   -2.4391   -2.9125   -4.4582   -4.3706
   -0.0043   -0.6533   -0.1824   -3.0540   -4.2141   -2.1411   -6.0532   -2.2221   -3.2234   -5.0006   -3.7829
   -0.0014   -0.4733    0.8337   -3.5500   -3.9524   -2.2802   -6.8867   -1.5642   -3.2897   -5.0291   -3.4404
    0.0034   -0.3162    0.9783   -3.5118   -3.6119   -2.6741   -7.2557   -1.4120   -3.5755   -4.8601   -3.2494
   -0.0004   -0.2088    1.4198   -3.0669   -3.1945   -2.3223   -7.0631   -1.5728   -3.6473   -4.6630   -2.7883
    0.0043    0.0558   -0.0892   -0.3658    0.0064   -0.4044    0.3747   -0.5703   -0.7800   -0.2853   -0.4268
   -0.0021    0.0156   -0.0765   -0.0886   -0.2696   -1.1274   -0.7470   -1.3923   -1.1149   -1.3337   -1.1652
   -0.0012   -0.4623   -0.8034   -1.7233   -2.0975   -1.9616   -2.4354   -1.7443   -2.6753   -1.9862   -0.8227
   -0.0042   -0.4843   -0.7270   -1.0289   -1.2786   -0.0372   -1.3345   -0.0013    0.5376   -0.6541    1.7004
    0.0027    0.4209    1.1946    2.0546    3.2873    3.9630    4.7559    4.5983    6.8171    3.3869    5.3895
   -0.0027    1.5357    4.0396    6.7355    8.5800    9.3953   11.2293   11.8386   13.0619    8.1486    9.6410
    0.0276    2.2115    5.9785   10.2136   11.7363   13.6151   16.1167   17.0691   16.4909   12.5501   11.8635
   -0.0009    1.5665    4.2372    9.3169   10.1525   13.1352   15.4799   16.0213   14.4682   13.0037   10.4473
    0.0009    1.1048    2.5196    6.8208    6.8739   10.3230   11.4879   11.9055   11.7542   10.4329    7.8470
    0.0051    0.4513    0.6672    4.4878    3.1793    6.4526    7.2751    7.6819    9.1493    7.4749    5.1408
   -0.0046   -0.0034   -0.6025    2.1435    0.4769    2.6127    2.6071    4.0118    6.0348    3.8447    2.8890
    0.0023   -0.4174   -1.3290    0.6061   -1.6986    0.0349   -0.8098    1.3637    3.3607    1.2856    1.2329
    0.0039   -0.6652   -2.1824   -1.2434   -2.8930   -2.0181   -3.1696   -0.3521    1.0887   -0.9015   -0.3141
   -0.0066   -0.9228   -2.3457   -2.7529   -3.4344   -2.6438   -4.8742   -1.8531   -1.0918   -2.6225   -1.7009
   -0.0004   -0.9820   -2.0459   -4.4010   -4.2238   -3.2852   -5.2511   -2.2186   -3.0822   -3.9306   -2.4450
    0.0051   -0.7647   -1.6507   -5.4738   -4.9860   -3.2043   -5.3069   -2.6661   -4.5374   -5.1194   -3.1255
   -0.0035   -0.8513   -0.9697   -5.4379   -4.8111   -3.1167   -5.9964   -2.8614   -5.5126   -5.5747   -2.9661
    0.0019   -0.6093   -0.0711   -5.9928   -4.1740   -2.8994   -6.8418   -2.3075   -6.0421   -5.5186   -2.8082
   -0.0028   -0.5724    0.2525   -5.9306   -3.3081   -2.9224   -7.2517   -2.0407   -6.4648   -5.2583   -2.8197
   -0.0012   -0.4711    0.4826   -5.2762   -2.9137   -2.7387   -7.5655   -2.0876   -6.6319   -4.6854   -2.6843
    0.0018    0.0728   -0.1117   -0.2910   -0.0923   -0.4908    0.1537   -0.6705   -0.8633   -0.3880   -0.2679
    0.0004    0.0452    0.0073   -0.3053    0.3333   -1.3991   -0.9766   -1.1680   -1.2965   -1.2414   -1.2674
   -0.0034   -0.2257   -0.4847   -1.9022   -1.7416   -2.3795   -3.3270   -2.5275   -2.8275   -2.3753   -1.6166
   -0.0053   -0.5329   -1.0854   -1.9418   -3.1264   -1.2286   -3.3756   -2.3168   -1.3970   -1.8751   -0.2049
    0.0015   -0.0518   -0.6430    0.3156   -0.4608    1.2337    0.9742    0.5786    2.5819    1.4884    2.5499
    0.0021    0.7228    1.5102    4.7854    4.5116    6.0345    7.6335    7.9765    8.7998    6.6714    6.6348
   -0.0009    1.5665    4.2372    9.3169   10.1525   13.1352   15.4799   16.0213   14.4682   13.0037   10.4473
    0.0314    2.6155    6.8339   12.7494   14.3347   18.6814   20.9964   20.5733   17.4530   17.2144   12.8438
    0.0022    2.2833    5.9653   11.4685   13.3280   17.7006   19.1894   18.8338   16.2822   16.2633   12.5154
    0.0031    1.5886    4.7836    9.3015   10.1134   13.8579   15.5878   14.7446   13.6874   13.9701   10.9961
    0.0050    0.8942    2.8596    6.1943    6.9848    8.9605   10.0224   10.3197    9.7601    9.8084    8.9139
    0.0012    0.3255    1.1149    3.5769    3.7360    5.4216    5.3772    6.5350    5.8943    6.3306    6.6238
   -0.0040   -0.0313   -0.2109    0.7784    1.2581    2.3678    1.9237    3.5411    2.9131    2.8755    4.4000
    0.0013   -0.3179   -1.2892   -1.0041   -0.8298    0.0431   -1.1233    1.0649   -0.0194    0.0528    2.5289
    0.0023   -0.7654   -2.0583   -3.2266   -2.5074   -2.1304   -2.4271   -0.5047   -2.8552   -2.1637    1.2212
   -0.0030   -0.9888   -2.6323   -5.2808   -4.0131   -3.0544   -3.0660   -1.8733   -5.0529   -4.0117   -0.0547
   -0.0030   -1.0324   -2.3898   -5.7711   -4.8576   -3.3466   -4.6338   -2.9189   -6.5811   -4.7788   -0.4795
    0.0022   -0.8982   -2.1161   -6.2645   -5.0246   -3.2853   -5.5915   -3.1156   -7.4639   -5.3981   -0.8321
    0.0018   -1.1244   -2.0315   -6.2563   -4.6313   -3.5396   -6.0717   -2.8953   -7.8800   -5.8144   -1.1659
   -0.0008   -1.1075   -1.9936   -5.7514   -4.4590   -3.7977   -6.9933   -2.9185   -8.0280   -5.7016   -1.4334
    0.0052    0.2183   -0.2003   -0.2498   -0.2042   -0.2190   -0.1759   -0.1397   -1.1468   -0.5703   -0.1509
   -0.0008    0.0800    0.1097   -0.4645    0.7635   -1.5371   -1.2177   -1.1003   -1.3366   -1.1036   -1.5881
    0.0006   -0.0466   -0.7316   -1.5319   -1.3293   -2.5203   -3.4525   -3.2862   -2.8240   -2.3830   -2.0122
   -0.0032   -0.6190   -1.0198   -2.3776   -3.4687   -1.6987   -4.4674   -3.8459   -2.3660   -2.3038   -1.3663
    0.0001   -0.6508   -1.2163   -1.4224   -3.0575    0.1875   -1.8317   -2.6914    0.3830   -0.0571    0.3879
   -0.0018   -0.0154   -0.1180    1.8418    0.5878    3.4821    3.4680    3.4707    6.0824    4.1911    3.5385
    0.0009    1.1048    2.5196    6.8208    6.8739   10.3230   11.4879   11.9055   11.7542   10.4329    7.8470
    0.0022    2.2833    5.9653   11.4685   13.3280   17.7006   19.1894   18.8338   16.2822   16.2633   12.5154
    0.0355    3.4245    8.3341   14.7042   17.5532   21.2448   22.1570   21.8789   18.9877   19.0888   15.7528
    0.0018    2.7766    7.9176   13.5722   16.0116   19.4507   20.9734   20.1888   18.1375   19.0595   16.0942
    0.0019    1.8718    6.0368   10.3151   13.5779   15.3734   16.0128   16.6632   14.7265   16.0538   14.5756
   -0.0005    1.1404    4.1270    7.3592    9.8721   11.5762   11.3301   12.5980   10.6838   12.5252   12.0874
    0.0001    0.3891    2.3157    3.9860    5.9052    7.8572    7.0491    8.3494    7.3265    8.3180    9.4014
   -0.0031   -0.0153    0.6882    1.6213    2.0814    4.6234    3.0095    4.9028    3.7169    4.7343    6.8722
    0.0018   -0.3179   -0.7997   -0.6252   -0.1493    1.5379    0.6627    2.3482    0.0275    1.8702    4.8215
    0.0005   -0.5558   -2.0271   -2.9337   -2.3418   -0.5910   -0.9337    0.0689   -3.0187   -0.5782    2.7751
    0.0008   -0.7390   -2.4745   -4.0773   -4.1647   -2.2109   -3.3397   -1.8096   -5.0781   -1.7308    1.7388
    0.0007   -0.7538   -2.9297   -4.9859   -5.3043   -3.1315   -4.7614   -2.8823   -6.5351   -2.7600    0.9793
   -0.0003   -1.0399   -3.1498   -5.6394   -5.5124   -4.2618   -5.3802   -3.2887   -7.6363   -3.8031    0.3414
    0.0030   -0.9421   -3.4925   -6.0200   -5.6381   -5.3374   -6.4911   -3.6750   -8.4123   -4.3672   -0.3471
    0.0016    0.2857   -0.1411   -0.1299   -0.5917   -0.0722   -0.1477    0.3492   -1.2950   -0.6080   -0.0244
    0.0010    0.0274    0.4339   -0.6609    0.8349   -1.4944   -1.3360   -1.4686   -1.0394   -1.1030   -1.6542
   -0.0019    0.0728   -0.7259   -1.6793   -0.6560   -2.7252   -3.6414   -3.4391   -2.9482   -2.6885   -2.2459
   -0.0026   -0.4567   -1.1928   -2.7360   -2.3947   -1.8508   -5.0264   -3.9514   -3.0336   -2.7895   -2.2434
   -0.0051   -0.7862   -1.9723   -2.7344   -3.3438   -0.4415   -3.1271   -3.8477   -0.5918   -1.3058   -1.5500
   -0.0011   -0.3695   -1.5013   -0.1513   -1.4689    1.6313    0.3413    0.7461    4.2402    2.0029    0.6268
    0.0051    0.4513    0.6672    4.4878    3.1793    6.4526    7.2751    7.6819    9.1493    7.4749    5.1408
    0.0031    1.5886    4.7836    9.3015   10.1134   13.8579   15.5878   14.7446   13.6874   13.9701   10.9961
    0.0018    2.7766    7.9176   13.5722   16.0116   19.4507   20.9734   20.1888   18.1375   19.0595   16.0942
    0.0339    3.7220   10.8169   16.4105   19.2302   22.4139   24.0238   23.0272   20.6332   22.6116   19.3768
   -0.0015    2.9583    9.4852   14.5788   18.6040   20.7644   20.8927   21.9370   19.0461   21.8337   19.6164
   -0.0024    2.2059    7.4633   11.5956   15.6700   17.8080   16.8193   18.4834   15.7278   19.2736   17.8874
    0.0005    1.4563    5.3963    7.9643   11.9421   14.3142   12.6117   14.2039   12.6911   15.3326   15.3830
    0.0018    0.8147    3.0634    5.0616    7.3360   10.6810    8.1090   10.4157    8.9793   11.5316   12.5178
   -0.0034    0.1363    0.4288    2.1071    4.1913    6.6324    4.7972    7.1774    4.6884    8.2441    9.6867
    0.0021   -0.3472   -1.5350   -0.7283    1.3521    3.1519    2.4514    4.1638    0.8634    4.8976    6.7943
   -0.0050   -0.4963   -2.5233   -2.7442   -0.9748    0.4682   -0.5968    1.4927   -1.8164    2.7149    4.7582
    0.0048   -0.7815   -3.5330   -4.1668   -3.5097   -1.5242   -2.3639   -0.2000   -4.1090    0.5635    3.2322
   -0.0006   -1.3522   -4.5583   -5.5234   -4.9214   -3.7172   -3.5627   -1.1551   -6.1125   -1.6114    1.8750
   -0.0037   -1.4912   -5.2506   -6.4746   -5.7832   -5.6852   -5.0676   -2.0995   -7.8147   -3.1947    0.5691
   -0.0016    0.2740    0.0782   -0.0639   -0.7747   -0.3772   -0.2502    0.4913   -1.5013   -0.5269   -0.0884
    0.0001    0.0637    0.5121   -0.5691    0.6220   -0.9371   -0.9417   -1.7541   -0.3254   -1.1635   -1.2265
    0.0010    0.0000   -0.8221   -1.5654   -0.6632   -2.7160   -2.9660   -3.4180   -2.8444   -2.8457   -2.1994
    0.0014   -0.2604   -0.9717   -2.5526   -1.5275   -1.6710   -4.4884   -3.6899   -3.2168   -3.4420   -2.8903
    0.0025   -0.4765   -2.0227   -2.3627   -3.1963   -0.6722   -3.4971   -3.9668   -1.0535   -2.5068   -2.8651
    0.0012   -0.5494   -2.2249   -1.0778   -2.8209   -0.1963   -1.9135   -1.0846    2.4377    0.0232   -1.1945
   -0.0046   -0.0034   -0.6025    2.1435    0.4769    2.6127    2.6071    4.0118    6.0348    3.8447    2.8890
    0.0050    0.8942    2.8596    6.1943    6.9848    8.9605   10.0224   10.3197    9.7601    9.8084    8.9139
    0.0019    1.8718    6.0368   10.3151   13.5779   15.3734   16.0128   16.6632   14.7265   16.0538   14.5756
   -0.0015    2.9583    9.4852   14.5788   18.6040   20.7644   20.8927   21.9370   19.0461   21.8337   19.6164
    0.0367    3.8787   11.2893   16.7529   22.3303   24.3492   22.6014   25.0995   21.2974   25.0897   22.7978
   -0.0042    3.3348   10.0658   14.7333   20.5758   23.1311   20.9072   23.2075   20.1603   25.0054   22.7898
    0.0015    2.6276    7.9872   11.7357   16.8501   20.2348   17.9238   19.6779   18.0195   22.5326   20.9938
   -0.0009    1.8598    5.5211    9.0878   12.0702   16.7049   13.9938   16.2887   14.9373   19.2207   18.3812
   -0.0022    1.0116    2.8562    6.0955    8.5694   12.0840   10.4232   12.6614   10.4538   15.9222   15.1352
    0.0016    0.2963    0.0983    2.8088    5.0414    7.6492    7.6174    9.2412    6.1263   12.0775   11.7038
   -0.0017   -0.0240   -1.8657   -0.0582    2.2595    3.6360    4.4424    5.8248    2.8989    8.9335    8.7666
    0.0053   -0.3577   -3.1029   -1.8196   -0.9053    0.6484    2.4161    3.4212   -0.2589    5.8051    6.1882
    0.0043   -0.8348   -4.2948   -3.5197   -3.0511   -2.4378    1.0193    1.9154   -2.9821    2.6169    3.8629
   -0.0004   -1.0509   -4.8336   -4.6123   -4.4919   -5.3470   -0.7272    0.4327   -5.4675    0.0274    1.7355
   -0.0015    0.2509    0.0997    0.1904   -0.3721   -0.4156   -0.2771    0.4581   -1.2154   -0.4789   -0.2745
    0.0045   -0.0509    0.4593   -0.4564    0.4639   -1.0334   -0.7965   -1.6280    0.2827   -1.2563   -0.7675
   -0.0008    0.0672   -0.5624   -1.3686   -0.6344   -2.1271   -2.4049   -2.9491   -2.8329   -3.1387   -2.1460
    0.0019   -0.0927   -0.5347   -2.2281   -0.9178   -1.3940   -3.8803   -3.3424   -3.1406   -4.0762   -3.2674
    0.0009   -0.3669   -1.6305   -1.8090   -2.8705   -1.0177   -3.5447   -3.4729   -1.1803   -3.2189   -3.4355
   -0.0024   -0.8109   -2.4620   -1.7003   -3.7049   -1.5007   -3.3493   -2.2810    1.2026   -1.2107   -2.1125
    0.0023   -0.4174   -1.3290    0.6061   -1.6986    0.0349   -0.8098    1.3637    3.3607    1.2856    1.2329
    0.0012    0.3255    1.1149    3.5769    3.7360    5.4216    5.3772    6.5350    5.8943    6.3306    6.6238
   -0.0005    1.1404    4.1270    7.3592    9.8721   11.5762   11.3301   12.5980   10.6838   12.5252   12.0874
   -0.0024    2.2059    7.4633   11.5956   15.6700   17.8080   16.8193   18.4834   15.7278   19.2736   17.8874
   -0.0042    3.3348   10.0658   14.7333   20.5758   23.1311   20.9072   23.2075   20.1603   25.0054   22.7898
    0.0378    4.2237   11.4643   16.0785   22.5874   26.5633   23.3904   24.7409   22.5523   28.3124   25.4391
   -0.0023    3.6361    9.9254   14.1723   20.5561   25.6221   22.6120   23.2646   22.1756   28.1339   25.3913
    0.0037    2.9756    7.7464   11.9921   16.4736   22.5068   20.1644   20.8203   20.0378   25.9845   23.7246
   -0.0026    2.2229    5.0686    8.9025   12.9782   17.6645   16.8579   17.5213   15.9764   23.2802   20.5586
   -0.0021    1.3816    2.3109    5.6320    9.6562   12.6822   13.9500   14.2154   11.7197   19.5398   16.9973
    0.0033    0.7607   -0.3137    2.4711    6.7159    7.9348   10.8578   10.7765    8.1246   15.9182   13.6873
   -0.0054    0.0765   -2.2084    0.0489    2.8190    3.7475    8.7524    8.1581    4.1651   12.0531   10.4671
   -0.0010   -0.4859   -3.6654   -1.9319   -0.1199   -0.0677    6.7923    6.1824    0.4445    7.9685    7.4161
   -0.0000   -0.7201   -4.3209   -3.2421   -2.2458   -3.5037    4.3658    4.2765   -2.6895    4.4868    4.5747
   -0.0032    0.2020    0.0538    0.4197   -0.0770   -0.3880   -0.0140    0.4938   -1.0378   -0.2600   -0.4313
   -0.0013   -0.0050    0.4040   -0.6721    0.1409   -0.9417   -0.9187   -1.7591    0.6004   -1.1302   -0.3745
    0.0023    0.1072   -0.3237   -1.2007   -0.6175   -1.6035   -1.9571   -2.3183   -2.8162   -3.2224   -1.7593
    0.0025   -0.0971   -0.2977   -1.6440   -0.5253   -1.5429   -3.5904   -2.7230   -3.3846   -4.5135   -3.2118
    0.0029   -0.2954   -1.3963   -0.5822   -2.4997   -1.4571   -3.9188   -2.9215   -1.6621   -3.6972   -3.8504
   -0.0014   -0.7919   -2.5938   -1.7307   -3.6840   -2.4828   -4.5885   -2.7551   -0.1687   -2.0954   -3.1177
    0.0039   -0.6652   -2.1824   -1.2434   -2.8930   -2.0181   -3.1696   -0.3521    1.0887   -0.9015   -0.3141
   -0.0040   -0.0313   -0.2109    0.7784    1.2581    2.3678    1.9237    3.5411    2.9131    2.8755    4.4000
    0.0001    0.3891    2.3157    3.9860    5.9052    7.8572    7.0491    8.3494    7.3265    8.3180    9.4014
    0.0005    1.4563    5.3963    7.9643   11.9421   14.3142   12.6117   14.2039   12.6911   15.3326   15.3830
    0.0015    2.6276    7.9872   11.7357   16.8501   20.2348   17.9238   19.6779   18.0195   22.5326   20.9938
   -0.0023    3.6361    9.9254   14.1723   20.5561   25.6221   22.6120   23.2646   22.1756   28.1339   25.3913
    0.0309    4.2678   10.9840   16.2840   22.8268   29.4264   25.8001   25.4521   24.7262   31.3517   27.7593
   -0.0007    3.8364    9.5574   15.6296   20.9983   27.9477   25.2705   24.7554   24.4975   31.1349   27.7408
    0.0037    3.2433    7.1452   13.4525   18.3883   23.8699   23.0147   22.2364   21.5688   29.5035   25.2369
    0.0010    2.4372    4.4488   10.6187   15.9335   19.2946   20.4861   19.3994   17.8152   26.2809   21.9169
   -0.0031    1.7138    1.5069    7.4597   13.2636   14.3946   17.8990   16.0917   14.2897   22.3868   18.6113
    0.0035    0.8659   -0.4236    4.5924    8.8688    9.6190   15.8008   13.4727   10.1243   18.0049   15.2631
   -0.0034   -0.0294   -2.2406    1.8462    4.9403    4.9415   13.1373   11.0309    5.9576   13.3245   11.9554
    0.0001   -0.5321   -3.1213   -0.3592    1.9214    0.7109    9.9908    8.6912    2.3809    9.1208    8.6560
    0.0010    0.1800   -0.0290    0.5894    0.2037   -0.4893    0.4674    0.2486   -1.1041    0.0673   -0.5176
   -0.0004    0.0283    0.4766   -0.6502   -0.2308   -0.6556   -0.8033   -1.6445    1.0563   -1.0888   -0.0945
    0.0006    0.2487    0.0577   -0.6569   -0.3470   -1.3811   -1.3119   -1.8392   -2.3609   -3.2287   -1.4374
    0.0027    0.1062   -0.1468   -1.0644    0.0335   -1.9772   -3.0998   -2.0346   -2.8750   -4.6021   -3.2944
   -0.0002   -0.1184   -1.1664    0.1328   -2.0151   -1.5931   -3.9415   -2.0988   -1.5047   -3.9133   -4.4160
   -0.0033   -0.7233   -1.9899   -2.1748   -3.1941   -2.4855   -5.3876   -3.1549   -1.2502   -2.7500   -4.0090
   -0.0066   -0.9228   -2.3457   -2.7529   -3.4344   -2.6438   -4.8742   -1.8531   -1.0918   -2.6225   -1.7009
    0.0013   -0.3179   -1.2892   -1.0041   -0.8298    0.0431   -1.1233    1.0649   -0.0194    0.0528    2.5289
   -0.0031   -0.0153    0.6882    1.6213    2.0814    4.6234    3.0095    4.9028    3.7169    4.7343    6.8722
    0.0018    0.8147    3.0634    5.0616    7.3360   10.6810    8.1090   10.4157    8.9793   11.5316   12.5178
   -0.0009    1.8598    5.5211    9.0878   12.0702   16.7049   13.9938   16.2887   14.9373   19.2207   18.3812
    0.0037    2.9756    7.7464   11.9921   16.4736   22.5068   20.1644   20.8203   20.0378   25.9845   23.7246
   -0.0007    3.8364    9.5574   15.6296   20.9983   27.9477   25.2705   24.7554   24.4975   31.1349   27.7408
    0.0345    4.8205   11.0474   18.4062   23.9561   30.2755   28.6292   27.3252   27.5550   33.7029   30.1359
    0.0016    4.3667    9.5480   17.3492   23.3871   28.1647   27.9957   26.6213   26.8050   33.8580   29.1237
   -0.0016    3.5692    7.5241   14.8856   22.3319   24.4105   26.3332   24.8703   24.0089   31.7091   26.7080
    0.0000    2.9076    4.7204   11.8579   20.2604   19.7937   24.2923   22.1647   20.8935   27.9705   23.8072
    0.0041    1.8681    2.9148    9.1007   15.8809   14.7581   22.2204   19.6747   16.8531   23.5003   20.6997
    0.0002    0.9252    0.8192    5.8235   11.4325   10.0204   19.4281   17.1518   12.5794   18.4941   17.4797
   -0.0018    0.1956   -0.2309    2.9687    8.1487    5.4560   15.9416   14.4273    8.7327   13.7924   13.9843
   -0.0025    0.0414   -0.0754    0.5759    0.2968   -0.3849    0.8755   -0.1418   -0.7844    0.1653   -0.5275
   -0.0023    0.1074    0.2998   -0.5323   -0.4062   -0.3740   -0.8232   -1.6375    1.2423   -1.0962   -0.1231
   -0.0041    0.3430    0.2268   -0.3774    0.2446   -0.9239   -1.1899   -1.4194   -1.9515   -3.4339   -1.1536
   -0.0012    0.0873   -0.2443   -0.9653   -0.0100   -2.2111   -2.9768   -1.2870   -2.5588   -4.9271   -3.0947
   -0.0006   -0.1689   -1.0508    0.0039   -2.8146   -2.1513   -4.0192   -1.0525   -1.7682   -4.4781   -4.4936
    0.0014   -0.7374   -1.5570   -2.9520   -3.8279   -2.7975   -5.5930   -2.7263   -2.3331   -3.5805   -4.3059
   -0.0004   -0.9820   -2.0459   -4.4010   -4.2238   -3.2852   -5.2511   -2.2186   -3.0822   -3.9306   -2.4450
    0.0023   -0.7654   -2.0583   -3.2266   -2.5074   -2.1304   -2.4271   -0.5047   -2.8552   -2.1637    1.2212
    0.0018   -0.3179   -0.7997   -0.6252   -0.1493    1.5379    0.6627    2.3482    0.0275    1.8702    4.8215
   -0.0034    0.1363    0.4288    2.1071    4.1913    6.6324    4.7972    7.1774    4.6884    8.2441    9.6867
   -0.0022    1.0116    2.8562    6.0955    8.5694   12.0840   10.4232   12.6614   10.4538   15.9222   15.1352
   -0.0026    2.2229    5.0686    8.9025   12.9782   17.6645   16.8579   17.5213   15.9764   23.2802   20.5586
    0.0037    3.2433    7.1452   13.4525   18.3883   23.8699   23.0147   22.2364   21.5688   29.5035   25.2369
    0.0016    4.3667    9.5480   17.3492   23.3871   28.1647   27.9957   26.6213   26.8050   33.8580   29.1237
    0.0369    5.4078   10.9382   20.1614   26.5162   30.0283   30.4823   29.1350   29.3892   36.6322   30.3872
   -0.0015    4.9616    9.9991   19.1213   27.3818   28.6498   30.2970   29.1806   28.5505   36.3482   29.5501
   -0.0029    4.3994    7.6717   16.8800   26.2519   25.5215   28.7259   27.5706   26.4521   33.3644   27.4920
   -0.0012    3.3032    6.1297   14.4740   22.6696   20.7101   27.1053   25.6231   23.0598   29.3248   24.9403
   -0.0019    2.5073    4.4942   11.2449   18.8010   16.3709   24.4335   23.2245   19.2083   24.4468   22.1303
   -0.0015    1.8511    3.4260    8.4120   15.6495   11.6843   20.6414   20.3059   15.7369   19.6180   18.8566
    0.0018   -0.0362   -0.0993    0.3358    0.5165   -0.5791    1.1286   -0.4110   -0.4273    0.1002   -0.6055
   -0.0034    0.1650    0.4411   -0.5062   -1.0353   -0.4403   -0.8068   -1.8705    1.3075   -1.2535    0.0442
    0.0072    0.2857    0.1554    0.2993    0.3077   -0.5706   -1.0562   -1.6818   -1.3149   -3.4402   -0.7579
   -0.0002   -0.0038   -0.3819   -0.3482   -0.1367   -1.7829   -2.8346   -0.7295   -1.9486   -5.3578   -2.7808
   -0.0016   -0.2909   -0.8262   -0.0102   -3.4887   -1.8165   -4.4152   -0.2485   -1.5214   -5.0463   -4.3685
   -0.0063   -0.5940   -0.8325   -3.3217   -4.3846   -2.1566   -5.8934   -2.4391   -2.9125   -4.4582   -4.3706
    0.0051   -0.7647   -1.6507   -5.4738   -4.9860   -3.2043   -5.3069   -2.6661   -4.5374   -5.1194   -3.1255
   -0.0030   -0.9888   -2.6323   -5.2808   -4.0131   -3.0544   -3.0660   -1.8733   -5.0529   -4.0117   -0.0547
    0.0005   -0.5558   -2.0271   -2.9337   -2.3418   -0.5910   -0.9337    0.0689   -3.0187   -0.5782    2.7751
    0.0021   -0.3472   -1.5350   -0.7283    1.3521    3.1519    2.4514    4.1638    0.8634    4.8976    6.7943
    0.0016    0.2963    0.0983    2.8088    5.0414    7.6492    7.6174    9.2412    6.1263   12.0775   11.7038
   -0.0021    1.3816    2.3109    5.6320    9.6562   12.6822   13.9500   14.2154   11.7197   19.5398   16.9973
    0.0010    2.4372    4.4488   10.6187   15.9335   19.2946   20.4861   19.3994   17.8152   26.2809   21.9169
   -0.0016    3.5692    7.5241   14.8856   22.3319   24.4105   26.3332   24.8703   24.0089   31.7091   26.7080
   -0.0015    4.9616    9.9991   19.1213   27.3818   28.6498   30.2970   29.1806   28.5505   36.3482   29.5501
    0.0424    5.9158   12.3083   21.5676   32.1720   31.6570   32.7572   32.3170   30.3718   38.9776   31.0319
    0.0011    5.5624   11.3677   20.5347   32.3349   30.4977   32.6811   32.7361   29.8352   37.5804   30.6208
    0.0048    4.5956   10.5257   18.6255   29.1939   26.4571   32.0343   31.7159   27.5592   34.4284   29.0226
   -0.0003    3.9874    9.2629   15.8464   25.7103   22.8166   29.9081   29.4439   24.4885   30.0453   26.9417
    0.0004    3.3629    8.2108   13.3413   22.6800   18.5711   26.2731   26.6319   21.7180   25.2841   24.1123
    0.0035   -0.1335   -0.1980    0.3119    0.4743   -0.6433    1.1277   -0.6699   -0.2558    0.0308   -0.6053
   -0.0062    0.1922    0.6176   -0.6027   -1.4757   -0.0658   -1.1273   -1.4792    1.0120   -1.2135    0.1377
   -0.0020    0.3652    0.0370    0.6082    0.8316   -0.0058   -0.9177   -1.4731   -0.7543   -3.1339   -0.5380
    0.0001    0.0762   -0.7114    0.0487   -0.3478   -1.8736   -2.4201   -0.4396   -1.3533   -5.1804   -2.3505
   -0.0057   -0.3424   -0.8189   -0.0217   -3.7996   -2.2883   -4.3321    0.2576   -1.1406   -5.3281   -3.8167
   -0.0043   -0.6533   -0.1824   -3.0540   -4.2141   -2.1411   -6.0532   -2.2221   -3.2234   -5.0006   -3.7829
   -0.0035   -0.8513   -0.9697   -5.4379   -4.8111   -3.1167   -5.9964   -2.8614   -5.5126   -5.5747   -2.9661
   -0.0030   -1.0324   -2.3898   -5.7711   -4.8576   -3.3466   -4.6338   -2.9189   -6.5811   -4.7788   -0.4795
    0.0008   -0.7390   -2.4745   -4.0773   -4.1647   -2.2109   -3.3397   -1.8096   -5.0781   -1.7308    1.7388
   -0.0050   -0.4963   -2.5233   -2.7442   -0.9748    0.4682   -0.5968    1.4927   -1.8164    2.7149    4.7582
   -0.0017   -0.0240   -1.8657   -0.0582    2.2595    3.6360    4.4424    5.8248    2.8989    8.9335    8.7666
    0.0033    0.7607   -0.3137    2.4711    6.7159    7.9348   10.8578   10.7765    8.1246   15.9182   13.6873
   -0.0031    1.7138    1.5069    7.4597   13.2636   14.3946   17.8990   16.0917   14.2897   22.3868   18.6113
    0.0000    2.9076    4.7204   11.8579   20.2604   19.7937   24.2923   22.1647   20.8935   27.9705   23.8072
   -0.0029    4.3994    7.6717   16.8800   26.2519   25.5215   28.7259   27.5706   26.4521   33.3644   27.4920
    0.0011    5.5624   11.3677   20.5347   32.3349   30.4977   32.6811   32.7361   29.8352   37.5804   30.6208
    0.0402    6.2260   13.5602   22.6717   35.3214   33.4436   36.0275   36.2682   31.7375   38.4698   32.5148
   -0.0010    5.5416   13.3944   21.8896   33.3362   31.2530   37.1093   36.9104   31.1767   36.9827   32.5955
    0.0015    5.0605   12.5674   19.6438   30.5331   29.1532   35.9217   35.2269   29.3484   33.6601   31.6592
    0.0073    4.6374   11.7517   17.7348   27.7895   26.0026   32.7072   32.9901   27.4706   29.5656   29.5265
   -0.0022   -0.1317   -0.2233    0.4120    0.3207   -0.6282    0.9466   -0.9286    0.2362   -0.0951   -0.5907
   -0.0020    0.2989    0.6774   -0.6683   -1.1892    0.2352   -1.2428   -1.2883    0.7901   -1.0259    0.1489
    0.0017    0.2849    0.0559    0.9455    0.8394    0.6334   -1.2524   -1.3635   -0.3568   -2.6516   -0.4342
   -0.0013    0.0422   -0.6242    0.4329   -0.8987   -1.4272   -2.3252   -0.2054   -0.8259   -4.9521   -2.0559
    0.0010   -0.2772   -0.4728   -0.4392   -4.1032   -2.2846   -4.9203    0.8002   -0.6600   -5.3431   -3.4955
   -0.0014   -0.4733    0.8337   -3.5500   -3.9524   -2.2802   -6.8867   -1.5642   -3.2897   -5.0291   -3.4404
    0.0019   -0.6093   -0.0711   -5.9928   -4.1740   -2.8994   -6.8418   -2.3075   -6.0421   -5.5186   -2.8082
    0.0022   -0.8982   -2.1161   -6.2645   -5.0246   -3.2853   -5.5915   -3.1156   -7.4639   -5.3981   -0.8321
    0.0007   -0.7538   -2.9297   -4.9859   -5.3043   -3.1315   -4.7614   -2.8823   -6.5351   -2.7600    0.9793
    0.0048   -0.7815   -3.5330   -4.1668   -3.5097   -1.5242   -2.3639   -0.2000   -4.1090    0.5635    3.2322
    0.0053   -0.3577   -3.1029   -1.8196   -0.9053    0.6484    2.4161    3.4212   -0.2589    5.8051    6.1882
   -0.0054    0.0765   -2.2084    0.0489    2.8190    3.7475    8.7524    8.1581    4.1651   12.0531   10.4671
    0.0035    0.8659   -0.4236    4.5924    8.8688    9.6190   15.8008   13.4727   10.1243   18.0049   15.2631
    0.0041    1.8681    2.9148    9.1007   15.8809   14.7581   22.2204   19.6747   16.8531   23.5003   20.6997
   -0.0012    3.3032    6.1297   14.4740   22.6696   20.7101   27.1053   25.6231   23.0598   29.3248   24.9403
    0.0048    4.5956   10.5257   18.6255   29.1939   26.4571   32.0343   31.7159   27.5592   34.4284   29.0226
   -0.0010    5.5416   13.3944   21.8896   33.3362   31.2530   37.1093   36.9104   31.1767   36.9827   32.5955
    0.0372    6.2924   15.9461   24.3506   34.6253   32.3290   40.9720   40.1308   33.3413   38.1810   34.9481
   -0.0018    6.0954   16.0872   23.3106   33.4577   32.3539   41.1707   39.7142   33.6534   36.6599   35.5756
    0.0005    5.8552   15.3604   22.0017   31.7717   30.4309   38.5834   38.3736   32.9152   33.7699   34.4239
    0.0059   -0.1355   -0.1730    0.3295    0.2481   -0.5139    0.6808   -1.0698    0.4774   -0.1787   -0.4314
   -0.0012    0.2417    0.4079   -0.5756   -1.0255    0.2406   -0.9616   -1.2962    0.6454   -1.0818    0.1149
   -0.0024    0.2144    0.0013    1.1034    0.7164    1.3769   -0.8448   -1.3856    0.2080   -2.0942   -0.3884
    0.0017    0.1893   -0.7751    0.5332   -1.8219   -1.0229   -2.0837   -0.3847   -0.7108   -4.5978   -1.7490
    0.0063   -0.1389   -0.5461   -0.5723   -4.4959   -2.4839   -5.3986    0.6829   -0.7736   -5.1949   -3.2421
    0.0034   -0.3162    0.9783   -3.5118   -3.6119   -2.6741   -7.2557   -1.4120   -3.5755   -4.8601   -3.2494
   -0.0028   -0.5724    0.2525   -5.9306   -3.3081   -2.9224   -7.2517   -2.0407   -6.4648   -5.2583   -2.8197
    0.0018   -1.1244   -2.0315   -6.2563   -4.6313   -3.5396   -6.0717   -2.8953   -7.8800   -5.8144   -1.1659
   -0.0003   -1.0399   -3.1498   -5.6394   -5.5124   -4.2618   -5.3802   -3.2887   -7.6363   -3.8031    0.3414
   -0.0006   -1.3522   -4.5583   -5.5234   -4.9214   -3.7172   -3.5627   -1.1551   -6.1125   -1.6114    1.8750
    0.0043   -0.8348   -4.2948   -3.5197   -3.0511   -2.4378    1.0193    1.9154   -2.9821    2.6169    3.8629
   -0.0010   -0.4859   -3.6654   -1.9319   -0.1199   -0.0677    6.7923    6.1824    0.4445    7.9685    7.4161
   -0.0034   -0.0294   -2.2406    1.8462    4.9403    4.9415   13.1373   11.0309    5.9576   13.3245   11.9554
    0.0002    0.9252    0.8192    5.8235   11.4325   10.0204   19.4281   17.1518   12.5794   18.4941   17.4797
   -0.0019    2.5073    4.4942   11.2449   18.8010   16.3709   24.4335   23.2245   19.2083   24.4468   22.1303
   -0.0003    3.9874    9.2629   15.8464   25.7103   22.8166   29.9081   29.4439   24.4885   30.0453   26.9417
    0.0015    5.0605   12.5674   19.6438   30.5331   29.1532   35.9217   35.2269   29.3484   33.6601   31.6592
   -0.0018    6.0954   16.0872   23.3106   33.4577   32.3539   41.1707   39.7142   33.6534   36.6599   35.5756
    0.0348    7.4916   18.9781   25.3988   35.6752   36.2927   44.1275   41.5934   37.2890   37.4985   38.0446
   -0.0049    7.7006   18.7788   25.1942   36.0218   36.5766   43.1702   41.7036   38.3721   36.3002   38.2273
   -0.0009   -0.0542   -0.3068    0.2893    0.2503   -0.7104    0.3833   -1.1104    0.7120   -0.2157   -0.3174
    0.0013    0.1360    0.2270   -0.4226   -1.5592    0.0365   -0.7469   -1.1931    0.3290   -1.3605    0.0305
   -0.0010    0.1235   -0.1527    0.7796    0.5380    2.1998   -0.6227   -1.1972    0.4515   -1.6198   -0.4645
    0.0006    0.1525   -0.4259    0.3732   -2.2185   -0.2860   -1.6442   -0.7217   -0.4848   -4.0251   -1.4922
   -0.0032   -0.1889   -0.0075   -0.5858   -4.2827   -2.0230   -5.3240    0.1828   -0.7470   -4.9822   -2.7540
   -0.0004   -0.2088    1.4198   -3.0669   -3.1945   -2.3223   -7.0631   -1.5728   -3.6473   -4.6630   -2.7883
   -0.0012   -0.4711    0.4826   -5.2762   -2.9137   -2.7387   -7.5655   -2.0876   -6.6319   -4.6854   -2.6843
   -0.0008   -1.1075   -1.9936   -5.7514   -4.4590   -3.7977   -6.9933   -2.9185   -8.0280   -5.7016   -1.4334
    0.0030   -0.9421   -3.4925   -6.0200   -5.6381   -5.3374   -6.4911   -3.6750   -8.4123   -4.3672   -0.3471
   -0.0037   -1.4912   -5.2506   -6.4746   -5.7832   -5.6852   -5.0676   -2.0995   -7.8147   -3.1947    0.5691
   -0.0004   -1.0509   -4.8336   -4.6123   -4.4919   -5.3470   -0.7272    0.4327   -5.4675    0.0274    1.7355
   -0.0000   -0.7201   -4.3209   -3.2421   -2.2458   -3.5037    4.3658    4.2765   -2.6895    4.4868    4.5747
    0.0001   -0.5321   -3.1213   -0.3592    1.9214    0.7109    9.9908    8.6912    2.3809    9.1208    8.6560
   -0.0018    0.1956   -0.2309    2.9687    8.1487    5.4560   15.9416   14.4273    8.7327   13.7924   13.9843
   -0.0015    1.8511    3.4260    8.4120   15.6495   11.6843   20.6414   20.3059   15.7369   19.6180   18.8566
    0.0004    3.3629    8.2108   13.3413   22.6800   18.5711   26.2731   26.6319   21.7180   25.2841   24.1123
    0.0073    4.6374   11.7517   17.7348   27.7895   26.0026   32.7072   32.9901   27.4706   29.5656   29.5265
    0.0005    5.8552   15.3604   22.0017   31.7717   30.4309   38.5834   38.3736   32.9152   33.7699   34.4239
   -0.0049    7.7006   18.7788   25.1942   36.0218   36.5766   43.1702   41.7036   38.3721   36.3002   38.2273
    0.0366    9.2927   20.7134   28.0587   40.1743   40.5470   45.2890   43.9418   41.8020   37.3232   40.0846];
M2=[1.7873    1.7136    1.3243    1.3780    1.0110    1.1144    0.7650
    0.0201   -0.1606   -0.2248   -0.0909    0.2961    0.6244    0.6766
   -0.3366   -0.3473   -0.6481   -0.2834    0.1131    0.4357    0.6316
   -0.8865   -0.3174   -0.4005   -0.2650    0.0932    0.2507    0.6646
   -0.7413   -0.0321   -0.0766   -0.1950    0.0762    0.2513    0.6530
   -0.6246    0.1686   -0.0721    0.0060   -0.0151    0.1766    0.5261
   -0.5523    0.0682   -0.1072    0.1121   -0.0988    0.1447    0.4758
   -0.7187   -0.0885   -0.2311    0.1779   -0.2275    0.1156    0.5796
   -0.7540   -0.1910   -0.2848    0.0573   -0.3507    0.0972    0.6442
   -0.7679   -0.3223   -0.2668   -0.0451   -0.3612    0.0443    0.7617
   -0.8479   -0.4040   -0.3311   -0.1729   -0.3313    0.0539    0.8430
   -1.1042   -0.4162   -0.4391   -0.2677   -0.2753    0.1051    0.8645
   -1.2205   -0.5665   -0.5199   -0.3770   -0.2460    0.1850    0.8623
   -1.1762   -0.7252   -0.5450   -0.4012   -0.2578    0.2271    0.8774
   -1.1268   -0.9361   -0.4575   -0.3269   -0.2515    0.2401    0.8835
   -1.0886   -1.0688   -0.5422   -0.2807   -0.2830    0.2258    0.9190
   -1.0437   -1.1124   -0.6047   -0.2764   -0.2916    0.2113    0.9493
   -0.9409   -1.0527   -0.6267   -0.3076   -0.3008    0.1890    0.9813
   -0.9303   -0.9861   -0.6633   -0.3768   -0.2651    0.1686    1.0115
   -0.9217   -0.8629   -0.7243   -0.4669   -0.2392    0.1769    1.0449
    0.0201   -0.1606   -0.2248   -0.0909    0.2961    0.6244    0.6766
    3.0383    3.5403    2.6549    2.3292    2.5249    2.3168    2.0864
    1.4327    1.8945    1.2881    1.4795    1.5869    1.9451    1.9008
   -0.0258    0.6612   -0.1764    0.9697    0.4068    1.5304    1.6195
   -0.2672    0.1603   -0.7849    0.8299    0.0019    1.2924    1.5832
   -0.2082   -0.2105   -0.7602    0.6195    0.0458    1.1078    1.4322
   -0.0493   -0.4028   -0.3744    0.4813   -0.0141    1.0835    1.3332
    0.1199   -0.5805    0.2055    0.3823   -0.1376    1.0502    1.3834
    0.1975   -0.4734    0.5995    0.4257   -0.1402    0.9399    1.3836
    0.4179   -0.5304    0.8659    0.4259   -0.2157    0.8031    1.5527
    0.6391   -0.2895    1.0035    0.3352   -0.1643    0.7259    1.7042
    0.7924    0.1674    1.1349    0.1129   -0.2499    0.6064    1.7341
    0.8304    0.4388    1.0914    0.0021   -0.4150    0.5178    1.7275
    0.7512    0.4158    0.9101   -0.1122   -0.4543    0.4677    1.7604
    0.4029    0.4005    0.8383   -0.3205   -0.4312    0.3876    1.7602
    0.0666    0.4036    0.7826   -0.4539   -0.4818    0.2927    1.7299
   -0.0085    0.3162    0.5796   -0.5019   -0.6615    0.2536    1.7510
   -0.0143    0.0777    0.3200   -0.5006   -0.8263    0.2685    1.7931
   -0.0848   -0.1573   -0.0932   -0.4996   -0.8660    0.3357    1.8402
   -0.1897   -0.2724   -0.4676   -0.5382   -0.8652    0.4499    1.8986
   -0.3366   -0.3473   -0.6481   -0.2834    0.1131    0.4357    0.6316
    1.4327    1.8945    1.2881    1.4795    1.5869    1.9451    1.9008
    5.6303    5.7291    4.0352    3.9144    3.7064    3.6282    3.0389
    3.8788    4.3038    2.6835    3.4586    2.8387    3.2242    2.7272
    1.3356    1.6913    1.1318    2.1414    1.3348    2.5379    2.3018
   -0.0793   -0.3617    0.4210    1.0214    0.7561    2.0219    1.9913
   -0.3546   -1.0383    0.0846    0.4376    0.3451    1.6864    1.9148
   -0.4546   -1.0819   -0.0804    0.2604    0.0818    1.4157    1.9859
   -0.4756   -0.7387   -0.1820    0.2733    0.0610    1.1052    1.9571
   -0.4009   -0.6669   -0.3805    0.3911    0.1029    0.8385    2.1410
    0.0013   -0.5022   -0.5797    0.3587    0.2948    0.7760    2.3161
    0.2500   -0.5243   -0.5917    0.3520    0.4157    0.7187    2.3304
    0.5789   -0.4981   -0.6144    0.2959    0.3389    0.6377    2.2911
    0.8190   -0.7161   -0.7660    0.2137    0.2028    0.5104    2.3114
    0.7103   -1.2253   -0.5837   -0.0301    0.1706    0.3267    2.3210
    0.4696   -1.3539   -0.2875   -0.0620    0.0788    0.2765    2.3336
    0.3923   -1.4075   -0.0934   -0.0064   -0.1031    0.3008    2.3726
    0.3258   -1.4762    0.1431    0.0499   -0.2641    0.3646    2.4019
    0.5251   -1.4651    0.1839    0.0052   -0.2940    0.4353    2.4594
    0.5748   -1.3235    0.2717   -0.0101   -0.2349    0.5408    2.5485
   -0.8865   -0.3174   -0.4005   -0.2650    0.0932    0.2507    0.6646
   -0.0258    0.6612   -0.1764    0.9697    0.4068    1.5304    1.6195
    3.8788    4.3038    2.6835    3.4586    2.8387    3.2242    2.7272
    8.0979    7.0299    5.2628    6.1605    4.7149    4.4642    3.6046
    6.7623    5.0233    4.2043    5.5962    3.8703    4.1579    3.6156
    3.8838    2.0324    2.3321    3.8505    2.6174    3.1345    3.2208
    1.7527    0.4273    0.9269    2.1611    1.5803    2.2290    2.9154
    0.7812   -0.2855   -0.0326    1.0539    1.1192    1.7506    2.8067
    0.0666   -0.4054   -0.4672    0.5681    0.9745    1.3892    2.6000
   -0.7538   -0.8618   -0.8601    0.3530    0.9769    1.0712    2.6376
   -1.0692   -1.1417   -1.1694    0.1421    1.1137    0.9146    2.7331
   -1.2124   -1.5203   -1.1841    0.2344    1.1733    0.7444    2.6763
   -1.1449   -1.6475   -1.1670    0.2289    1.0073    0.5874    2.6661
   -0.9927   -2.0737   -1.0776    0.1455    0.7532    0.3793    2.7378
   -0.7825   -2.5487   -0.7332   -0.1479    0.6498    0.1173    2.7854
   -0.8408   -2.6465   -0.3511   -0.1864    0.4919    0.0770    2.8843
   -0.9722   -2.4518    0.0049   -0.1421    0.3180    0.0860    3.0368
   -1.4066   -2.0748    0.4288   -0.1799    0.1697    0.1403    3.1212
   -1.4447   -1.6590    0.6954   -0.2741    0.1429    0.1641    3.1797
   -1.5427   -1.1497    0.9364   -0.2997    0.1714    0.1845    3.2639
   -0.7413   -0.0321   -0.0766   -0.1950    0.0762    0.2513    0.6530
   -0.2672    0.1603   -0.7849    0.8299    0.0019    1.2924    1.5832
    1.3356    1.6913    1.1318    2.1414    1.3348    2.5379    2.3018
    6.7623    5.0233    4.2043    5.5962    3.8703    4.1579    3.6156
   10.2682    6.5722    6.3187    7.8178    5.2083    5.2884    4.8588
    8.9028    5.5898    5.7891    6.9984    4.8686    4.8689    5.0052
    5.7667    3.9221    4.0377    4.8225    3.8990    3.8817    4.6469
    3.0729    2.4187    2.1315    3.0005    3.1525    3.0583    4.3684
    0.9532    1.3604    1.0067    1.9289    2.4628    2.3753    4.0053
   -0.9844    0.3819    0.1806    1.1843    2.0635    1.8125    3.8391
   -1.9874   -0.1729   -0.4529    0.6456    1.8146    1.4477    3.7902
   -2.4456   -0.8664   -0.7064    0.4883    1.6580    1.1470    3.6061
   -2.4243   -1.1433   -1.0841    0.3230    1.3411    0.9787    3.4852
   -2.2166   -1.7928   -1.3802    0.1298    1.0544    0.8035    3.4884
   -1.8495   -2.4720   -1.3590   -0.1282    0.9462    0.5416    3.4937
   -1.7615   -2.8221   -1.1686   -0.2113    0.7899    0.4352    3.5544
   -1.7067   -2.9904   -0.9659   -0.2413    0.5860    0.4301    3.7497
   -2.0124   -2.9807   -0.5987   -0.4844    0.4260    0.4680    3.8708
   -2.1035   -2.8559   -0.3879   -0.7247    0.2898    0.4020    3.9305
   -2.2582   -2.4676   -0.2422   -0.8816    0.1571    0.3320    3.9844
   -0.6246    0.1686   -0.0721    0.0060   -0.0151    0.1766    0.5261
   -0.2082   -0.2105   -0.7602    0.6195    0.0458    1.1078    1.4322
   -0.0793   -0.3617    0.4210    1.0214    0.7561    2.0219    1.9913
    3.8838    2.0324    2.3321    3.8505    2.6174    3.1345    3.2208
    8.9028    5.5898    5.7891    6.9984    4.8686    4.8689    5.0052
   11.0892    8.7382    7.8994    8.3171    6.4055    5.9020    6.0481
    9.5838    8.9639    7.1910    7.1572    6.3944    5.6653    6.1853
    6.9296    7.5360    5.3112    5.5560    5.8072    4.8581    6.0505
    4.0754    5.7053    3.6841    4.0657    4.6648    3.7913    5.6417
    1.3098    3.7961    2.2867    2.7695    3.7647    2.8027    5.2560
   -0.3827    2.4412    1.1591    1.8963    3.0782    2.1562    4.9774
   -1.3822    1.2458    0.3440    1.2630    2.5343    1.6972    4.5953
   -2.0155    0.7232   -0.6056    0.7700    1.9505    1.4362    4.2909
   -2.1163   -0.2381   -1.4378    0.2717    1.5211    1.2682    4.1376
   -1.8536   -1.1098   -1.8087   -0.0661    1.2900    1.0419    4.0117
   -1.7003   -1.6405   -1.9353   -0.2665    1.0428    0.9334    3.9471
   -1.6765   -2.2183   -1.9570   -0.3874    0.7533    0.9179    4.0663
   -2.0532   -2.8517   -1.7398   -0.7450    0.5328    0.9269    4.1151
   -2.3253   -3.2525   -1.5337   -0.9890    0.2995    0.8366    4.1016
   -2.5742   -3.3028   -1.4273   -1.1613    0.1073    0.7522    4.0707
   -0.5523    0.0682   -0.1072    0.1121   -0.0988    0.1447    0.4758
   -0.0493   -0.4028   -0.3744    0.4813   -0.0141    1.0835    1.3332
   -0.3546   -1.0383    0.0846    0.4376    0.3451    1.6864    1.9148
    1.7527    0.4273    0.9269    2.1611    1.5803    2.2290    2.9154
    5.7667    3.9221    4.0377    4.8225    3.8990    3.8817    4.6469
    9.5838    8.9639    7.1910    7.1572    6.3944    5.6653    6.1853
   12.2361   12.1899    8.8952    8.2465    7.8379    6.7107    7.2603
   11.5967   11.9664    8.5648    7.8512    7.9401    6.5521    7.6846
    9.3389   10.3514    7.5141    6.6971    6.8013    5.5733    7.5390
    6.3362    7.8285    5.8337    5.2073    5.6326    4.4217    7.1021
    3.8037    5.6351    4.0740    3.8606    4.4735    3.4645    6.5978
    1.7061    3.8307    2.3223    2.6660    3.4742    2.7249    6.0054
    0.0096    3.0018    0.5632    1.7790    2.5557    2.2354    5.5672
   -0.9199    1.8248   -0.9535    0.8899    1.9457    1.9541    5.3374
   -1.2966    0.7311   -1.8653    0.3132    1.5846    1.6808    5.1414
   -1.6744    0.0172   -2.4362   -0.1426    1.2925    1.5131    5.0039
   -2.1508   -0.6931   -2.8302   -0.4019    0.9843    1.4467    5.1095
   -2.8421   -1.5592   -2.9401   -0.7561    0.7668    1.3860    5.1459
   -3.0883   -2.1319   -3.0124   -0.9034    0.5037    1.2728    5.1080
   -3.2363   -2.4549   -3.0365   -1.0264    0.3228    1.1935    5.0352
   -0.7187   -0.0885   -0.2311    0.1779   -0.2275    0.1156    0.5796
    0.1199   -0.5805    0.2055    0.3823   -0.1376    1.0502    1.3834
   -0.4546   -1.0819   -0.0804    0.2604    0.0818    1.4157    1.9859
    0.7812   -0.2855   -0.0326    1.0539    1.1192    1.7506    2.8067
    3.0729    2.4187    2.1315    3.0005    3.1525    3.0583    4.3684
    6.9296    7.5360    5.3112    5.5560    5.8072    4.8581    6.0505
   11.5967   11.9664    8.5648    7.8512    7.9401    6.5521    7.6846
   14.3383   14.0051   10.7912    9.3597    9.2753    7.4325    8.8512
   13.8711   13.6605   11.0374    9.2817    8.8470    7.0345    9.1990
   11.6939   11.5461    9.7126    8.1699    7.9038    6.1331    8.9482
    9.1158    9.2265    7.8379    6.7129    6.5864    5.1001    8.4309
    6.3876    6.9949    5.4700    5.1093    5.2313    4.1550    7.6845
    3.9264    5.7044    3.0581    3.7621    3.9302    3.4224    7.0972
    2.0244    4.2022    1.0148    2.4853    3.0167    2.9136    6.7357
    0.8922    2.6889   -0.2349    1.6361    2.4146    2.5088    6.4207
   -0.1471    1.5694   -1.1433    0.9544    2.0020    2.2463    6.1944
   -1.0510    0.5999   -1.9027    0.5103    1.5895    2.1217    6.2769
   -2.1126   -0.5222   -2.4421    0.1352    1.2700    2.0160    6.3188
   -2.5399   -1.3034   -2.9563   -0.0190    0.9361    1.8957    6.2741
   -2.8612   -1.8388   -3.2968   -0.1182    0.6930    1.8267    6.1804
   -0.7540   -0.1910   -0.2848    0.0573   -0.3507    0.0972    0.6442
    0.1975   -0.4734    0.5995    0.4257   -0.1402    0.9399    1.3836
   -0.4756   -0.7387   -0.1820    0.2733    0.0610    1.1052    1.9571
    0.0666   -0.4054   -0.4672    0.5681    0.9745    1.3892    2.6000
    0.9532    1.3604    1.0067    1.9289    2.4628    2.3753    4.0053
    4.0754    5.7053    3.6841    4.0657    4.6648    3.7913    5.6417
    9.3389   10.3514    7.5141    6.6971    6.8013    5.5733    7.5390
   13.8711   13.6605   11.0374    9.2817    8.8470    7.0345    9.1990
   16.5478   15.3772   12.9947   10.9491    9.8790    7.6375   10.2538
   16.2831   14.4579   12.6376   10.9216    9.7975    7.3744   10.4458
   14.3337   12.5857   11.0519    9.8757    8.8590    6.5675   10.1312
   11.5875   10.3793    8.6084    8.3019    7.5899    5.6845    9.4005
    8.7144    8.8696    5.8286    6.7505    6.1521    4.8351    8.7474
    5.9815    7.0978    3.3914    5.0387    4.9554    4.0749    8.2665
    4.1296    5.2352    1.7412    3.7441    3.9896    3.4816    7.8026
    2.3187    3.7564    0.4845    2.6475    3.2659    3.1002    7.4617
    0.7891    2.5490   -0.6626    1.8648    2.6385    2.8873    7.4967
   -0.7432    1.2090   -1.6583    1.2684    2.1319    2.6940    7.5284
   -1.6209    0.0762   -2.6583    0.9006    1.6883    2.5101    7.4857
   -2.3477   -0.7875   -3.4433    0.6416    1.3699    2.4070    7.3864
   -0.7679   -0.3223   -0.2668   -0.0451   -0.3612    0.0443    0.7617
    0.4179   -0.5304    0.8659    0.4259   -0.2157    0.8031    1.5527
   -0.4009   -0.6669   -0.3805    0.3911    0.1029    0.8385    2.1410
   -0.7538   -0.8618   -0.8601    0.3530    0.9769    1.0712    2.6376
   -0.9844    0.3819    0.1806    1.1843    2.0635    1.8125    3.8391
    1.3098    3.7961    2.2867    2.7695    3.7647    2.8027    5.2560
    6.3362    7.8285    5.8337    5.2073    5.6326    4.4217    7.1021
   11.6939   11.5461    9.7126    8.1699    7.9038    6.1331    8.9482
   16.2831   14.4579   12.6376   10.9216    9.7975    7.3744   10.4458
   18.9912   15.7726   14.1065   12.3816   11.0020    8.0143   11.2733
   18.8992   15.3118   13.7596   12.3241   10.9585    7.8043   11.3836
   17.0010   13.7744   12.1132   11.2663   10.1670    7.2559   10.8081
   14.4575   12.5556    9.7283    9.9171    8.9343    6.5472   10.1831
   11.6588   10.9199    7.3984    8.1475    7.6706    5.7559    9.6643
    9.2514    8.8998    5.5447    6.6423    6.4881    5.0822    9.1214
    6.5547    7.1099    3.9651    5.2756    5.4329    4.5947    8.6794
    4.3321    5.6000    2.3959    4.1811    4.5095    4.2415    8.6548
    2.2701    3.9380    0.8469    3.2752    3.7202    3.9135    8.6533
    0.8407    2.4604   -0.7331    2.5600    3.0861    3.6066    8.6096
   -0.4388    1.2954   -2.0893    2.0256    2.5888    3.3653    8.5223
   -0.8479   -0.4040   -0.3311   -0.1729   -0.3313    0.0539    0.8430
    0.6391   -0.2895    1.0035    0.3352   -0.1643    0.7259    1.7042
    0.0013   -0.5022   -0.5797    0.3587    0.2948    0.7760    2.3161
   -1.0692   -1.1417   -1.1694    0.1421    1.1137    0.9146    2.7331
   -1.9874   -0.1729   -0.4529    0.6456    1.8146    1.4477    3.7902
   -0.3827    2.4412    1.1591    1.8963    3.0782    2.1562    4.9774
    3.8037    5.6351    4.0740    3.8606    4.4735    3.4645    6.5978
    9.1158    9.2265    7.8379    6.7129    6.5864    5.1001    8.4309
   14.3337   12.5857   11.0519    9.8757    8.8590    6.5675   10.1312
   18.8992   15.3118   13.7596   12.3241   10.9585    7.8043   11.3836
   21.5469   16.9438   15.1727   13.7818   12.1710    8.4509   12.1017
   21.2113   16.7491   14.9200   13.7486   12.2452    8.5330   11.9051
   19.5719   16.2683   13.4020   13.0440   11.5505    8.1953   11.4658
   17.3653   15.0489   11.6270   11.6735   10.5020    7.5970   11.0114
   14.8772   13.1677    9.9218   10.3300    9.3471    7.0110   10.4558
   11.8061   11.2476    8.2067    8.9405    8.1097    6.4840    9.9563
    9.1945    9.4859    6.3751    7.6149    6.9326    5.9890    9.8779
    6.7230    7.5425    4.3796    6.3198    5.8463    5.5196    9.8204
    4.7740    5.7192    2.2834    5.2101    5.0145    5.0768    9.7405
    2.9984    4.2587    0.4130    4.3819    4.3530    4.6769    9.6209
   -1.1042   -0.4162   -0.4391   -0.2677   -0.2753    0.1051    0.8645
    0.7924    0.1674    1.1349    0.1129   -0.2499    0.6064    1.7341
    0.2500   -0.5243   -0.5917    0.3520    0.4157    0.7187    2.3304
   -1.2124   -1.5203   -1.1841    0.2344    1.1733    0.7444    2.6763
   -2.4456   -0.8664   -0.7064    0.4883    1.6580    1.1470    3.6061
   -1.3822    1.2458    0.3440    1.2630    2.5343    1.6972    4.5953
    1.7061    3.8307    2.3223    2.6660    3.4742    2.7249    6.0054
    6.3876    6.9949    5.4700    5.1093    5.2313    4.1550    7.6845
   11.5875   10.3793    8.6084    8.3019    7.5899    5.6845    9.4005
   17.0010   13.7744   12.1132   11.2663   10.1670    7.2559   10.8081
   21.2113   16.7491   14.9200   13.7486   12.2452    8.5330   11.9051
   23.3525   18.4729   16.7989   14.9833   13.3485    9.4301   12.2472
   23.5395   19.2200   16.8789   15.1955   13.4126    9.6598   12.1713
   22.4094   18.7571   16.1344   14.4228   12.7866    9.4296   11.9394
   20.2442   17.3283   14.9213   13.3804   11.8465    9.0831   11.4970
   17.2200   15.5494   13.3213   12.0974   10.6323    8.6059   11.0617
   14.4421   13.7540   11.4039   10.6680    9.4142    8.0252   10.9968
   11.7128   11.7265    9.0313    9.0942    8.1887    7.4408   10.8995
    9.1806    9.6655    6.4645    7.5904    7.1976    6.8825   10.7714
    6.7621    7.9190    4.1127    6.3860    6.4061    6.3319   10.5905
   -1.2205   -0.5665   -0.5199   -0.3770   -0.2460    0.1850    0.8623
    0.8304    0.4388    1.0914    0.0021   -0.4150    0.5178    1.7275
    0.5789   -0.4981   -0.6144    0.2959    0.3389    0.6377    2.2911
   -1.1449   -1.6475   -1.1670    0.2289    1.0073    0.5874    2.6661
   -2.4243   -1.1433   -1.0841    0.3230    1.3411    0.9787    3.4852
   -2.0155    0.7232   -0.6056    0.7700    1.9505    1.4362    4.2909
    0.0096    3.0018    0.5632    1.7790    2.5557    2.2354    5.5672
    3.9264    5.7044    3.0581    3.7621    3.9302    3.4224    7.0972
    8.7144    8.8696    5.8286    6.7505    6.1521    4.8351    8.7474
   14.4575   12.5556    9.7283    9.9171    8.9343    6.5472   10.1831
   19.5719   16.2683   13.4020   13.0440   11.5505    8.1953   11.4658
   23.5395   19.2200   16.8789   15.1955   13.4126    9.6598   12.1713
   26.1825   21.6497   19.0039   16.5634   14.4726   10.6354   12.5698
   26.5897   22.3859   19.7213   16.6859   14.5406   10.9856   12.6946
   25.1549   21.7546   19.3054   16.1740   14.0206   11.0412   12.4702
   22.4929   20.2945   18.1163   15.1558   13.0310   10.7495   12.1811
   19.9339   18.5771   16.4508   13.7590   11.9598   10.1953   12.1784
   17.2056   16.5126   14.0226   12.0651   10.7957    9.6122   12.0983
   14.3826   14.1859   11.3020   10.2956    9.7778    9.0230   11.9446
   11.4879   12.0340    8.7158    8.7930    8.9193    8.3588   11.7024
   -1.1762   -0.7252   -0.5450   -0.4012   -0.2578    0.2271    0.8774
    0.7512    0.4158    0.9101   -0.1122   -0.4543    0.4677    1.7604
    0.8190   -0.7161   -0.7660    0.2137    0.2028    0.5104    2.3114
   -0.9927   -2.0737   -1.0776    0.1455    0.7532    0.3793    2.7378
   -2.2166   -1.7928   -1.3802    0.1298    1.0544    0.8035    3.4884
   -2.1163   -0.2381   -1.4378    0.2717    1.5211    1.2682    4.1376
   -0.9199    1.8248   -0.9535    0.8899    1.9457    1.9541    5.3374
    2.0244    4.2022    1.0148    2.4853    3.0167    2.9136    6.7357
    5.9815    7.0978    3.3914    5.0387    4.9554    4.0749    8.2665
   11.6588   10.9199    7.3984    8.1475    7.6706    5.7559    9.6643
   17.3653   15.0489   11.6270   11.6735   10.5020    7.5970   11.0114
   22.4094   18.7571   16.1344   14.4228   12.7866    9.4296   11.9394
   26.5897   22.3859   19.7213   16.6859   14.5406   10.9856   12.6946
   28.9304   24.8791   22.1421   18.0509   15.4894   12.0454   13.2573
   28.7193   25.5180   22.8712   18.4427   15.6047   12.6539   13.3589
   26.8852   24.7226   22.3417   17.9278   15.0368   12.6659   13.2887
   24.7190   23.3816   21.1679   16.7647   14.2414   12.2462   13.3935
   22.0531   21.5118   18.9481   15.1526   13.2684   11.7462   13.3710
   19.1031   19.0507   16.2805   13.2900   12.3246   11.1916   13.2324
   15.9230   16.5423   13.5848   11.6353   11.4557   10.4742   12.9753
   -1.1268   -0.9361   -0.4575   -0.3269   -0.2515    0.2401    0.8835
    0.4029    0.4005    0.8383   -0.3205   -0.4312    0.3876    1.7602
    0.7103   -1.2253   -0.5837   -0.0301    0.1706    0.3267    2.3210
   -0.7825   -2.5487   -0.7332   -0.1479    0.6498    0.1173    2.7854
   -1.8495   -2.4720   -1.3590   -0.1282    0.9462    0.5416    3.4937
   -1.8536   -1.1098   -1.8087   -0.0661    1.2900    1.0419    4.0117
   -1.2966    0.7311   -1.8653    0.3132    1.5846    1.6808    5.1414
    0.8922    2.6889   -0.2349    1.6361    2.4146    2.5088    6.4207
    4.1296    5.2352    1.7412    3.7441    3.9896    3.4816    7.8026
    9.2514    8.8998    5.5447    6.6423    6.4881    5.0822    9.1214
   14.8772   13.1677    9.9218   10.3300    9.3471    7.0110   10.4558
   20.2442   17.3283   14.9213   13.3804   11.8465    9.0831   11.4970
   25.1549   21.7546   19.3054   16.1740   14.0206   11.0412   12.4702
   28.7193   25.5180   22.8712   18.4427   15.6047   12.6539   13.3589
   30.3968   27.9904   25.0093   19.9264   16.5335   13.9125   13.9217
   30.0773   28.4460   25.4845   20.1767   16.6233   14.3710   14.2086
   28.6730   27.8932   24.9967   19.4677   16.2198   14.2276   14.5302
   26.3369   26.5631   23.2095   18.1273   15.5494   13.9111   14.6591
   23.4972   24.2480   20.8125   16.3441   14.8188   13.4649   14.6249
   20.2733   21.5478   18.2109   14.6731   14.0807   12.7463   14.4484
   -1.0886   -1.0688   -0.5422   -0.2807   -0.2830    0.2258    0.9190
    0.0666    0.4036    0.7826   -0.4539   -0.4818    0.2927    1.7299
    0.4696   -1.3539   -0.2875   -0.0620    0.0788    0.2765    2.3336
   -0.8408   -2.6465   -0.3511   -0.1864    0.4919    0.0770    2.8843
   -1.7615   -2.8221   -1.1686   -0.2113    0.7899    0.4352    3.5544
   -1.7003   -1.6405   -1.9353   -0.2665    1.0428    0.9334    3.9471
   -1.6744    0.0172   -2.4362   -0.1426    1.2925    1.5131    5.0039
   -0.1471    1.5694   -1.1433    0.9544    2.0020    2.2463    6.1944
    2.3187    3.7564    0.4845    2.6475    3.2659    3.1002    7.4617
    6.5547    7.1099    3.9651    5.2756    5.4329    4.5947    8.6794
   11.8061   11.2476    8.2067    8.9405    8.1097    6.4840    9.9563
   17.2200   15.5494   13.3213   12.0974   10.6323    8.6059   11.0617
   22.4929   20.2945   18.1163   15.1558   13.0310   10.7495   12.1811
   26.8852   24.7226   22.3417   17.9278   15.0368   12.6659   13.2887
   30.0773   28.4460   25.4845   20.1767   16.6233   14.3710   14.2086
   32.0451   30.4485   27.2743   21.4604   17.5533   15.3982   14.9241
   32.2094   31.0237   27.8035   21.5150   17.7452   15.6853   15.5496
   30.7796   30.4652   26.7233   20.6679   17.5156   15.6468   15.8916
   28.4716   28.5397   24.8387   19.1319   17.1124   15.3960   16.0025
   25.6163   25.9211   22.5759   17.5886   16.6032   14.7914   15.9447
   -1.0437   -1.1124   -0.6047   -0.2764   -0.2916    0.2113    0.9493
   -0.0085    0.3162    0.5796   -0.5019   -0.6615    0.2536    1.7510
    0.3923   -1.4075   -0.0934   -0.0064   -0.1031    0.3008    2.3726
   -0.9722   -2.4518    0.0049   -0.1421    0.3180    0.0860    3.0368
   -1.7067   -2.9904   -0.9659   -0.2413    0.5860    0.4301    3.7497
   -1.6765   -2.2183   -1.9570   -0.3874    0.7533    0.9179    4.0663
   -2.1508   -0.6931   -2.8302   -0.4019    0.9843    1.4467    5.1095
   -1.0510    0.5999   -1.9027    0.5103    1.5895    2.1217    6.2769
    0.7891    2.5490   -0.6626    1.8648    2.6385    2.8873    7.4967
    4.3321    5.6000    2.3959    4.1811    4.5095    4.2415    8.6548
    9.1945    9.4859    6.3751    7.6149    6.9326    5.9890    9.8779
   14.4421   13.7540   11.4039   10.6680    9.4142    8.0252   10.9968
   19.9339   18.5771   16.4508   13.7590   11.9598   10.1953   12.1784
   24.7190   23.3816   21.1679   16.7647   14.2414   12.2462   13.3935
   28.6730   27.8932   24.9967   19.4677   16.2198   14.2276   14.5302
   32.2094   31.0237   27.8035   21.5150   17.7452   15.6853   15.5496
   34.2859   33.0049   29.5217   22.4731   18.6317   16.5581   16.5174
   34.1710   33.5015   29.3558   22.3462   18.9696   16.9590   17.1189
   32.6795   32.2108   28.1731   21.2632   18.9918   17.0115   17.4068
   30.3787   29.8794   26.3987   20.0258   18.7807   16.6624   17.4787
   -0.9409   -1.0527   -0.6267   -0.3076   -0.3008    0.1890    0.9813
   -0.0143    0.0777    0.3200   -0.5006   -0.8263    0.2685    1.7931
    0.3258   -1.4762    0.1431    0.0499   -0.2641    0.3646    2.4019
   -1.4066   -2.0748    0.4288   -0.1799    0.1697    0.1403    3.1212
   -2.0124   -2.9807   -0.5987   -0.4844    0.4260    0.4680    3.8708
   -2.0532   -2.8517   -1.7398   -0.7450    0.5328    0.9269    4.1151
   -2.8421   -1.5592   -2.9401   -0.7561    0.7668    1.3860    5.1459
   -2.1126   -0.5222   -2.4421    0.1352    1.2700    2.0160    6.3188
   -0.7432    1.2090   -1.6583    1.2684    2.1319    2.6940    7.5284
    2.2701    3.9380    0.8469    3.2752    3.7202    3.9135    8.6533
    6.7230    7.5425    4.3796    6.3198    5.8463    5.5196    9.8204
   11.7128   11.7265    9.0313    9.0942    8.1887    7.4408   10.8995
   17.2056   16.5126   14.0226   12.0651   10.7957    9.6122   12.0983
   22.0531   21.5118   18.9481   15.1526   13.2684   11.7462   13.3710
   26.3369   26.5631   23.2095   18.1273   15.5494   13.9111   14.6591
   30.7796   30.4652   26.7233   20.6679   17.5156   15.6468   15.8916
   34.1710   33.5015   29.3558   22.3462   18.9696   16.9590   17.1189
   35.7473   35.3961   30.3521   23.1525   20.0032   17.8806   18.0134
   35.4900   35.1279   30.1140   22.7911   20.5781   18.3560   18.5275
   34.0491   33.3564   28.9888   22.0538   20.7384   18.3518   18.7683
   -0.9303   -0.9861   -0.6633   -0.3768   -0.2651    0.1686    1.0115
   -0.0848   -0.1573   -0.0932   -0.4996   -0.8660    0.3357    1.8402
    0.5251   -1.4651    0.1839    0.0052   -0.2940    0.4353    2.4594
   -1.4447   -1.6590    0.6954   -0.2741    0.1429    0.1641    3.1797
   -2.1035   -2.8559   -0.3879   -0.7247    0.2898    0.4020    3.9305
   -2.3253   -3.2525   -1.5337   -0.9890    0.2995    0.8366    4.1016
   -3.0883   -2.1319   -3.0124   -0.9034    0.5037    1.2728    5.1080
   -2.5399   -1.3034   -2.9563   -0.0190    0.9361    1.8957    6.2741
   -1.6209    0.0762   -2.6583    0.9006    1.6883    2.5101    7.4857
    0.8407    2.4604   -0.7331    2.5600    3.0861    3.6066    8.6096
    4.7740    5.7192    2.2834    5.2101    5.0145    5.0768    9.7405
    9.1806    9.6655    6.4645    7.5904    7.1976    6.8825   10.7714
   14.3826   14.1859   11.3020   10.2956    9.7778    9.0230   11.9446
   19.1031   19.0507   16.2805   13.2900   12.3246   11.1916   13.2324
   23.4972   24.2480   20.8125   16.3441   14.8188   13.4649   14.6249
   28.4716   28.5397   24.8387   19.1319   17.1124   15.3960   16.0025
   32.6795   32.2108   28.1731   21.2632   18.9918   17.0115   17.4068
   35.4900   35.1279   30.1140   22.7911   20.5781   18.3560   18.5275
   36.9525   36.1832   31.0850   23.3951   21.8139   19.3250   19.3077
   36.8712   35.3989   30.8755   23.4539   22.4983   19.7373   19.7775
   -0.9217   -0.8629   -0.7243   -0.4669   -0.2392    0.1769    1.0449
   -0.1897   -0.2724   -0.4676   -0.5382   -0.8652    0.4499    1.8986
    0.5748   -1.3235    0.2717   -0.0101   -0.2349    0.5408    2.5485
   -1.5427   -1.1497    0.9364   -0.2997    0.1714    0.1845    3.2639
   -2.2582   -2.4676   -0.2422   -0.8816    0.1571    0.3320    3.9844
   -2.5742   -3.3028   -1.4273   -1.1613    0.1073    0.7522    4.0707
   -3.2363   -2.4549   -3.0365   -1.0264    0.3228    1.1935    5.0352
   -2.8612   -1.8388   -3.2968   -0.1182    0.6930    1.8267    6.1804
   -2.3477   -0.7875   -3.4433    0.6416    1.3699    2.4070    7.3864
   -0.4388    1.2954   -2.0893    2.0256    2.5888    3.3653    8.5223
    2.9984    4.2587    0.4130    4.3819    4.3530    4.6769    9.6209
    6.7621    7.9190    4.1127    6.3860    6.4061    6.3319   10.5905
   11.4879   12.0340    8.7158    8.7930    8.9193    8.3588   11.7024
   15.9230   16.5423   13.5848   11.6353   11.4557   10.4742   12.9753
   20.2733   21.5478   18.2109   14.6731   14.0807   12.7463   14.4484
   25.6163   25.9211   22.5759   17.5886   16.6032   14.7914   15.9447
   30.3787   29.8794   26.3987   20.0258   18.7807   16.6624   17.4787
   34.0491   33.3564   28.9888   22.0538   20.7384   18.3518   18.7683
   36.8712   35.3989   30.8755   23.4539   22.4983   19.7373   19.7775
   38.4748   35.8679   31.7202   24.5132   23.8154   20.6626   20.5260];
M=[M1,M2];
if d>=1.20
    d=1.19999;
end

dfix=fix(10*(0.5+d))+1;
MM=10*((d+0.5-0.1*(dfix-1))*M(:,(dfix+1))+(dfix*0.1-0.5-d)*M(:,(dfix)));
MMM=0;
for i=1:20
    for j=1:20
        MMM(i,j)=MM((j-1)*20+i);
    end
end
sig=MMM(1:p,1:p);